@@ -1,6 +1,6 @@
 /* gstyle-eyedropper.h
  *
- * Copyright (C) 2016 sebastien lafargue <slafargue@gnome.org>
+ * Copyright 2016 sebastien lafargue <slafargue@gnome.org>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,10 +14,11 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#ifndef GSTYLE_EYEDROPPER_H
-#define GSTYLE_EYEDROPPER_H
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -31,5 +32,3 @@ G_DECLARE_FINAL_TYPE (GstyleEyedropper, gstyle_eyedropper, GSTYLE, EYEDROPPER, G
 GstyleEyedropper       *gstyle_eyedropper_new       (GdkEvent       *event);
 
 G_END_DECLS
-
-#endif /* GSTYLE_EYEDROPPER_H */
